
#ifndef IMAGETOOLS_EXPORT_H
#define IMAGETOOLS_EXPORT_H

#ifdef IMAGETOOLS_STATIC_DEFINE
#  define IMAGETOOLS_EXPORT
#  define IMAGETOOLS_NO_EXPORT
#else
#  ifndef IMAGETOOLS_EXPORT
#    ifdef MauiKitImageTools4_EXPORTS
        /* We are building this library */
#      define IMAGETOOLS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define IMAGETOOLS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef IMAGETOOLS_NO_EXPORT
#    define IMAGETOOLS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef IMAGETOOLS_DEPRECATED
#  define IMAGETOOLS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef IMAGETOOLS_DEPRECATED_EXPORT
#  define IMAGETOOLS_DEPRECATED_EXPORT IMAGETOOLS_EXPORT IMAGETOOLS_DEPRECATED
#endif

#ifndef IMAGETOOLS_DEPRECATED_NO_EXPORT
#  define IMAGETOOLS_DEPRECATED_NO_EXPORT IMAGETOOLS_NO_EXPORT IMAGETOOLS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef IMAGETOOLS_NO_DEPRECATED
#    define IMAGETOOLS_NO_DEPRECATED
#  endif
#endif

#endif /* IMAGETOOLS_EXPORT_H */
